.. KM3Pipe documentation master file, created by
   sphinx-quickstart on Sat Oct  4 19:16:43 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst

Contents
========

.. toctree::
   :maxdepth: 1

   quick_start
   data_structures
   file_formats
   help_modules
   help_pumps
   examples
   pipeinspector
   api/modules


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

